//	Copyright  1995 Apple Computer, Inc. All rights reserved.
//	Release Version:	$ 1.0 d11 $

//=======================================================================
#ifndef _MNUFRAME_
#include "MnuFrm.h"				// CMnuFrame
#endif

#ifndef MNUPRT_H
#include "MnuPrt.h"				// CMnuPart
#endif

#ifndef CONSTANT_H
#include "Constant.h"			// my menu command numbers
#endif

// ----- Framework Layer -----
#ifndef FWUTIL_H
#include "FWUtil.h"				// FW_CFacetContext, FW_Beep()
#endif

// ----- OS Layer -----
#ifndef FWMENU_H
#include "FWMenu.h"				// FW_CMenuBar, etc.
#endif

#ifndef FWEVENT_H
#include "FWEvent.h"			// FW_CMenuEvent, FW_CMouseEvent
#endif

#ifndef FWALERT_H
#include "FWAlert.h"			// FW_CAlert
#endif

// ----- Graphic Includes -----
#ifndef FWRECT_H
#include <FWRect.h>				// FW_CRect
#endif

#ifndef FWRECSHP_H
#include "FWRecShp.h"			// FW_CRectShape
#endif

//========================================================================================
#ifdef FW_BUILD_MAC
#pragma segment Mnu
#endif

//========================================================================================
CMnuFrame::CMnuFrame(Environment* ev, ODFrame* odFrame, 
									FW_CPresentation* presentation, CMnuPart* mnuPart)
  : FW_CFrame(ev, odFrame, presentation, mnuPart),
	fMnuPart(mnuPart),
	fSoundOn(TRUE)
{
}

//----------------------------------------------------------------------------------------
CMnuFrame::~CMnuFrame()
{
}

//----------------------------------------------------------------------------------------
void 
CMnuFrame::Draw(Environment *ev, ODFacet* odFacet, ODShape* invalidShape)	// Override
{
	FW_CViewContext context(ev, this, odFacet, invalidShape);
	FW_CRect invalidRect;
	context.GetClipRect(invalidRect);

	FW_CRectShape::RenderRect(context, invalidRect, FW_kFill, FW_kWhiteEraseInk); // erase

	FW_CRect mnuRect = this->GetBounds(ev);
	FW_CRectShape rectShape(mnuRect, FW_kFill);
	rectShape.GetInk()->SetForeColor(FW_kRGBLightGray);
	rectShape.Render(context);
}

//----------------------------------------------------------------------------------------
FW_Boolean 
CMnuFrame::DoAdjustMenus(Environment* ev, FW_CMenuBar* menuBar, FW_Boolean hasMenuFocus,
													FW_Boolean isRoot)	// Override
{
	if (hasMenuFocus) {
		menuBar->EnableCommand(ev, cItemThreeCommand, TRUE);
		menuBar->EnableAndCheckCommand(ev, cSoundOnOffCommand, 
												TRUE, 			// enable
												fSoundOn);		// checkmark
	}
	return FALSE;
}

//----------------------------------------------------------------------------------------
FW_Boolean 
CMnuFrame::DoMenu(Environment* ev, const FW_CMenuEvent& theMenuEvent)	// Override
{
	FW_Boolean menuHandled = TRUE;
	
	switch (theMenuEvent.GetCommandID(ev))
	{
		case cItemThreeCommand:
			if (fSoundOn) FW_Beep();
			break;

		case cSoundOnOffCommand:
			fSoundOn = !fSoundOn;
			break;

		default:
			menuHandled = FALSE;
	}
	return menuHandled;
}

