//	Copyright  1995 Apple Computer, Inc. All rights reserved.
//	Release Version:	$ 1.0 d8 $

//================================================================================
#ifndef MNUPRT_H
#include "MnuPrt.h"			// CMnuPart
#endif

#ifndef _MNUFRAME_
#include "MnuFrm.h"			// CMnuFrame
#endif

#ifndef CONSTANT_H
#include "Constant.h"		// my menu command numbers
#endif

// ----- Framework Layer -----
#ifndef FWPRESEN_H
#include "FWPresen.h"		// FW_CPresentation
#endif

#ifndef FWUTIL_H
#include "FWUtil.h"			// FW_Beep()
#endif

#ifndef FWABOUT_H
#include "FWAbout.h"		//::FW_About()
#endif

// ----- OS Layer -----
#ifndef   FWRESFIL_H
#include "FWResFil.h"		// FW_CResourceFile
#endif

#ifndef FWMENU_H
#include "FWMenu.h"			// FW_CMenuBar, FW_CPullDownMenu
#endif

#ifndef FWCFMRES_H
#include "FWCFMRes.h"		// FW_CSharedLibraryResourceFile
#endif

#ifndef FWRESTYP_H
#include "FWResTyp.h"		// MULTISTRINGRES
#endif

#ifndef FWEVENT_H
#include "FWEvent.h"		// FW_CMenuEvent
#endif

#ifndef FWSUSINK_H
#include "FWSUSink.h"		// FW_CStorageUnitSink
#endif

//==============================================================================
const ODValueType CMnuPart::kPartKind = kMnuKind;
const ODValueType CMnuPart::kPartUserName = kMnuEditorUserString;

//==============================================================================
#ifdef FW_BUILD_WIN16
	extern HANDLE far gWinInstance;		// Initialized by LibMain
#endif

#ifdef FW_BUILD_MAC
#pragma segment Mnu
#endif

//==============================================================================
CMnuPart::CMnuPart(ODPart* odPart)
  :	FW_CPart(odPart, kPartKind, kPartUserName, FW_gInstance, kPartIconID),
	fPresentation(NULL)
{
}

//--------------------------------------------------------------------------------
CMnuPart::~CMnuPart()
{
}

//--------------------------------------------------------------------------------
void 
CMnuPart::Initialize(Environment* ev)	// Override
{
	FW_CPart::Initialize(ev);
	fPresentation = RegisterPresentation(ev, kMainPresentation, TRUE, NULL);
	this->MyInitMenus(ev);
}

//--------------------------------------------------------------------------------
void 
CMnuPart::MyInitMenus(Environment* ev)
{
	FW_CSharedLibraryResourceFile resFile;
	
	// create part menu
	FW_CPullDownMenu* partMenu = new FW_CPullDownMenu(ev, resFile, 
											kMenuStringsResID, kPartMenuStringID);
	partMenu->AppendTextItem(ev, resFile, kMenuStringsResID, 
										kItemOneStringID, cItemOneCommand, '1');
	partMenu->AppendTextItem(ev, resFile, kMenuStringsResID, 
										kItemTwoStringID, cItemTwoCommand, '2');
	this->GetMenuBar(ev)->AdoptMenuLast(ev, partMenu);

	// create frame menu
	FW_CPullDownMenu* frameMenu = new FW_CPullDownMenu(ev, resFile, 
											kMenuStringsResID, kFrameMenuStringID);
	frameMenu->AppendTextItem(ev, resFile, kMenuStringsResID, 
										kItemThreeStringID, cItemThreeCommand, '3');
	frameMenu->AppendSeparator(ev);		// dashed line
	frameMenu->AppendTextItem(ev, resFile, kMenuStringsResID, 
										kSoundStringID, cSoundOnOffCommand, '4');
	this->GetMenuBar(ev)->AdoptMenuLast(ev, frameMenu);
}

//--------------------------------------------------------------------------------
FW_Boolean 
CMnuPart::DoAdjustMenus(Environment* ev, FW_CMenuBar* menuBar, 
									 FW_Boolean hasMenuFocus,
									 FW_Boolean isRoot)	// Override
{
	if (hasMenuFocus) {	
		// Set up the About menu item
		FW_CString32 aboutString;
		this->MyGetResourceString(kAboutBoxStrings, kAboutMenuString, aboutString);
		menuBar->SetItemString(ev, kODCommandAbout, aboutString);
		menuBar->EnableCommand(ev, kODCommandAbout, TRUE);
	
		// Set up the part menu
		menuBar->EnableCommand(ev, cItemOneCommand, TRUE);
		menuBar->EnableCommand(ev, cItemTwoCommand, TRUE);
	}
	return FALSE;
}

//--------------------------------------------------------------------------------
FW_Boolean 
CMnuPart::DoMenu(Environment* ev, const FW_CMenuEvent& theMenuEvent)	// Override
{
	FW_Boolean menuHandled = TRUE;
	ODCommandID commandID = theMenuEvent.GetCommandID(ev);
	
	switch (commandID)
	{
		case kODCommandAbout:
			::FW_About(FW_gInstance);	// uses DLOG 300 from "MacAbout.rsrc"
			break;

		case cItemOneCommand:
			fPresentation->Invalidate(ev);
			break;

		case cItemTwoCommand:
			fPresentation->Invalidate(ev);
			break;

		default:
			menuHandled = FALSE;
	}
	return menuHandled;
}

//--------------------------------------------------------------------------------
FW_CFrame* 
CMnuPart::NewFrame(Environment* ev, ODFrame* odFrame,
						FW_CPresentation* presentation, FW_Boolean fromStorage)	// Override
{
	FW_UNUSED(presentation);
	FW_UNUSED(fromStorage);
	return new CMnuFrame(ev, odFrame, presentation, this);
}

//--------------------------------------------------------------------------------
void 
CMnuPart::MyGetResourceString(FW_ResourceId multiStringId,
								   FW_ResourceId stringId,
								   FW_CString& string)
{
	FW_CSharedLibraryResourceFile resFile;
	::FW_LoadStringByID(resFile, multiStringId, MULTISTRINGRES, stringId, string);
}

